/* This header file provides the C-interface for melange to create 
 * the Dylan code necessary to call-out to these routines
 *
 * Copyright (c) 2000, GPL
 * written by Douglas M. Auclair, dauclair@hotmail.com */

#ifndef COUNTER_H
#define COUNTER_H

void countdown(void);
void wait_seconds(int);

#endif
